@@ -27,7 +27,7 @@ QQplot = function(x, y, n = 20,
 
   ## scale x and y
   x.sc = (x-mean(x))/sd(x); y.sc = (y-mean(y))/sd(y)
-  
+
   zip = function(x,y,do.na = TRUE) {
     ## alternate x,y
     k = length(x)
@@ -56,7 +56,8 @@ QQplot = function(x, y, n = 20,
 
   ## return y value for given x value
   findInDensity= function(x,dens) {
-    if(class(dens) == "density" & !is.na(x)) {
+  kls = class(dens)
+    if(kls == "density" & !is.na(x)) {
       if(any(dens$x < x)) {
         i = max(which(dens$x < x))
         dens$y[i]
@@ -67,13 +68,13 @@ QQplot = function(x, y, n = 20,
       return(NA)
     }
   }
-  
-  
+
+
   ## n should be even
   k = n %/% 2                           # half of n
   n = k * 2 - 1
   vals = (1:(n-1))/(n)
-  
+
   dens = list(
     x= density(x.sc),
     y = density(y.sc)
@@ -87,14 +88,14 @@ QQplot = function(x, y, n = 20,
   xlim = c(min(dens$x$x) - ysf*max(dens$y$y),max(dens$x$x))
   ylim = c(min(dens$y$x) - xsf*max(dens$x$y),max(dens$y$x))
 
-  
+
   plot.new()
   plot.window(xlim=xlim,ylim=ylim,...)
   title(main=main,xlab=xlab,ylab=ylab)
-  
+
   lines(xlim,rep(min(dens$y$x),2))
   lines(rep(min(dens$x$x),2),ylim)
-  
+
   ## x first
   lines(dens$x$x,min(dens$y$x) - xsf*dens$x$y, type="l",xaxt="n",yaxt="n")
 
@@ -111,7 +112,7 @@ QQplot = function(x, y, n = 20,
     x=new.x,
     y=new.y)
 
-  
+
   ## y now
   lines(min(dens$x$x)-ysf*dens$y$y,dens$y$x,xaxt="n",yaxt="n")
 
@@ -133,5 +134,3 @@ QQplot = function(x, y, n = 20,
   lines(zip(qpts$x,qpts$x),zip(rep(min(dens$y$x),n-1),qpts$y), lty=lty)
   lines(zip(rep(min(dens$x$x),n-1),qpts$x),zip(qpts$y,qpts$y), lty=lty)
 }
-
-
